.. image:: https://readthedocs.org/projects/pyscaffold-demo/badge/?version=latest
    :alt: ReadTheDocs
    :target: https://pyscaffold-demo.readthedocs.io/

.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/demo-project.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/demo-project
    .. image:: https://readthedocs.org/projects/demo-project/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://demo-project.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/demo-project/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/demo-project
    .. image:: https://img.shields.io/pypi/v/demo-project.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/demo-project/
    .. image:: https://img.shields.io/conda/vn/conda-forge/demo-project.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/demo-project
    .. image:: https://pepy.tech/badge/demo-project/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/demo-project
    .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
        :alt: Twitter
        :target: https://twitter.com/demo-project

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

============
Ljpeg
============


     Read and transform ljpeg images into tiff or jpeg


Transform an image with::

     ljpeg $(pwd)/C_0029_1.LEFT_CC.LJPEG $(pwd)/output.tiff

Transform a lot of images parallely::

     find "$(pwd)" -type f -name '*.LJPEG' | parallel -j+0 "$(pwd)/ljpeg/ljpeg.py {} $(pwd)/{/.}.tiff --verify"


.. _pyscaffold-notes:

Making Changes & Contributing
=============================

This project uses `pre-commit`_, please make sure to install it before making any
changes::

    pip install pre-commit
    cd demo-project
    pre-commit install

It is a good idea to update the hooks to the latest version::

    pre-commit autoupdate

Don't forget to tell your contributors to also install and use pre-commit.

.. _pre-commit: https://pre-commit.com/

Note
====

This project has been set up using PyScaffold 4.2.2.post1.dev3+g01e6e81. For details and usage
information on PyScaffold see https://pyscaffold.org/.
